pub struct ValidatorRegistry { /* private fields */ }Expand description
Registry that maps FileType values to validator factories.
This is the extension point for the validation engine. A
ValidatorRegistry owns a set of ValidatorFactory functions for each
supported FileType, and constructs concrete Validator instances on
demand.
Most callers should use ValidatorRegistry::with_defaults to obtain a
registry pre-populated with all built-in validators.
Implementations
Sourceimpl ValidatorRegistry
impl ValidatorRegistry
Sourcepub fn with_defaults() -> Self
pub fn with_defaults() -> Self
Create a registry pre-populated with built-in validators.
Sourcepub fn register(&mut self, file_type: FileType, factory: ValidatorFactory)
pub fn register(&mut self, file_type: FileType, factory: ValidatorFactory)
Register a validator factory for a given file type.